@@ -2,13 +2,13 @@ import tensorflow as tf
 
 import kgcnn.ops.activ
 
+
 class GraphBaseLayer(tf.keras.layers.Layer):
     """Base layer for graph layers used in kgcnn that holds some additional information about the graph, which can
     improve performance, if set differently.
 
     Args:
         node_indexing (str): Indices referring to 'sample' or to the continuous 'batch'.
-            For disjoint representation 'batch' is default.
         partition_type (str): Partition tensor type to assign nodes or edges to batch. Default is "row_length".
             This is used for input_tensor_type="values_partition".
         input_tensor_type (str): Tensor input type. Default is "RaggedTensor".
@@ -56,6 +56,9 @@ class GraphBaseLayer(tf.keras.layers.Layer):
                             "is_sorted": self.is_sorted, "has_unconnected": self.has_unconnected,
                             "output_tensor_type": self.output_tensor_type, "is_directed": self.is_directed}
 
+        if self.node_indexing != "sample":
+            raise ValueError("Indexing for disjoint representation is not supported as of version 1.0")
+
     def _kgcnn_static_tensor_input_check(self):
 
         if self.input_tensor_type not in self._tensor_input_type_known:
@@ -89,8 +92,8 @@ class GraphBaseLayer(tf.keras.layers.Layer):
             for i, ips in enumerate(input_shape):
                 if isinstance(ips, tf.TensorShape):
                     if ips[-1] is None:
-                        print("WARNING: Layer", self.name, "has undefined inner dimension", ips, "for input", i)
+                        print("WARNING:kgcnn: Layer", self.name, "has undefined inner dimension", ips, "for input", i)
         if isinstance(input_shape, tf.TensorShape):
             if input_shape[-1] is None:
-                print("WARNING: Layer", self.name, "has undefined inner dimension for input", input_shape)
+                print("WARNING:kgcnn: Layer", self.name, "has undefined inner dimension for input", input_shape)
 
