@@ -13,22 +13,28 @@ import rdkit.Chem.Descriptors
 class OneHotEncoder:
     """Simple One-Hot-Encoding for python lists. Uses a list of possible values for a one-hot encoding of a single
     value. The translated values must support ``__eq__()`` operator. The list of possible values must be set beforehand.
-    Is used as a basic encoder example for ``MolecularGraphRDKit``.
+    Is used as a basic encoder example for ``MolecularGraphRDKit``. There can not be different dtypes in categories.
     """
+    _dtype_translate = {"int": int, "float": float, "str": str}
 
-    def __init__(self, one_hot_values: list, add_others: bool = True):
+    def __init__(self, categories: list, add_unknown: bool = True, dtype: str = "int"):
         """Initialize the encoder beforehand with a set of all possible values to encounter.
 
         Args:
-            one_hot_values (list): List of possible values, matching the one-hot encoding.
-            add_others (bool): Whether to add a unknown bit. Default is True.
+            categories (list): List of possible values, matching the one-hot encoding.
+            add_unknown (bool): Whether to add a unknown bit. Default is True.
         """
-        self.one_hot_values = one_hot_values
+        assert isinstance(dtype, str)
+        if dtype not in ["str", "int", "float"]:
+            raise ValueError("ERROR:kgnn: Unsupported dtype for OneHotEncoder %s" % dtype)
+        self.dtype_identifier = dtype
+        self.dtype = self._dtype_translate[dtype]
+        self.categories = [self.dtype(x) for x in categories]
         self.found_values = []
-        self.add_others = add_others
+        self.add_unknown = add_unknown
 
     def __call__(self, value, **kwargs):
-        r"""Encode a single value mapping it to a one-hot python list. E.g. `[0, 0, 1, 0]`
+        r"""Encode a single feature or value, mapping it to a one-hot python list. E.g. `[0, 0, 1, 0]`
 
         Args:
             value: Any object that can be compared to items in ``self.one_hot_values``.
@@ -37,9 +43,9 @@ class OneHotEncoder:
         Returns:
             list: Python list with 1 at value match. E.g. `[0, 0, 1, 0]`
         """
-        encoded_list = [1 if x == value else 0 for x in self.one_hot_values]
-        if self.add_others:
-            if value not in self.one_hot_values:
+        encoded_list = [1 if x == self.dtype(value) else 0 for x in self.categories]
+        if self.add_unknown:
+            if value not in self.categories:
                 encoded_list += [1]
             else:
                 encoded_list += [0]
@@ -47,6 +53,14 @@ class OneHotEncoder:
             self.found_values += [value]
         return encoded_list
 
+    def get_config(self):
+        config = {"categories": self.categories, "add_unknown": self.add_unknown, "dtype": self.dtype_identifier}
+        return config
+
+    @classmethod
+    def from_config(cls, config):
+        return cls(**config)
+
 
 class MolGraphInterface:
     r"""The `MolGraphInterface` defines the base class interface to handle a molecular graph. The method implementation
@@ -214,32 +228,32 @@ class MolecularGraphRDKit(MolGraphInterface):
     """A graph object representing a strict molecular graph, e.g. only chemical bonds."""
 
     atom_fun_dict = {
-        "AtomicNum": rdkit.Chem.rdchem.Atom.GetAtomicNum,
-        "Symbol": rdkit.Chem.rdchem.Atom.GetSymbol,
-        "NumExplicitHs": rdkit.Chem.rdchem.Atom.GetNumExplicitHs,
-        "NumImplicitHs": rdkit.Chem.rdchem.Atom.GetNumImplicitHs,
-        "TotalNumHs": rdkit.Chem.rdchem.Atom.GetTotalNumHs,
-        "IsAromatic": rdkit.Chem.rdchem.Atom.GetIsAromatic,
-        "TotalDegree": rdkit.Chem.rdchem.Atom.GetTotalDegree,
-        "TotalValence": rdkit.Chem.rdchem.Atom.GetTotalValence,
-        "Mass": rdkit.Chem.rdchem.Atom.GetMass,
-        "IsInRing": rdkit.Chem.rdchem.Atom.IsInRing,
-        "Hybridization": rdkit.Chem.rdchem.Atom.GetHybridization,
-        "ChiralTag": rdkit.Chem.rdchem.Atom.GetChiralTag,
-        "FormalCharge": rdkit.Chem.rdchem.Atom.GetFormalCharge,
-        "ImplicitValence": rdkit.Chem.rdchem.Atom.GetImplicitValence,
-        "NumRadicalElectrons": rdkit.Chem.rdchem.Atom.GetNumRadicalElectrons,
-        "Idx": rdkit.Chem.rdchem.Atom.GetIdx,
+        "AtomicNum": lambda atom: atom.GetAtomicNum(),
+        "Symbol": lambda atom: atom.GetSymbol(),
+        "NumExplicitHs": lambda atom: atom.GetNumExplicitHs(),
+        "NumImplicitHs": lambda atom: atom.GetNumImplicitHs(),
+        "TotalNumHs": lambda atom: atom.GetTotalNumHs(),
+        "IsAromatic": lambda atom: atom.GetIsAromatic(),
+        "TotalDegree": lambda atom: atom.GetTotalDegree(),
+        "TotalValence": lambda atom: atom.GetTotalValence(),
+        "Mass": lambda atom: atom.GetMass(),
+        "IsInRing": lambda atom: atom.IsInRing(),
+        "Hybridization": lambda atom: atom.GetHybridization(),
+        "ChiralTag": lambda atom: atom.GetChiralTag(),
+        "FormalCharge": lambda atom: atom.GetFormalCharge(),
+        "ImplicitValence": lambda atom: atom.GetImplicitValence(),
+        "NumRadicalElectrons": lambda atom: atom.GetNumRadicalElectrons(),
+        "Idx": lambda atom: atom.GetIdx(),
         "CIPCode": lambda atom: atom.GetProp('_CIPCode') if atom.HasProp('_CIPCode') else False,
         "ChiralityPossible": lambda atom: atom.HasProp('_ChiralityPossible')
     }
 
     bond_fun_dict = {
-        "BondType": rdkit.Chem.rdchem.Bond.GetBondType,
-        "IsAromatic": rdkit.Chem.rdchem.Bond.GetIsAromatic,
-        "IsConjugated": rdkit.Chem.rdchem.Bond.GetIsConjugated,
-        "IsInRing": rdkit.Chem.rdchem.Bond.IsInRing,
-        "Stereo": rdkit.Chem.rdchem.Bond.GetStereo
+        "BondType": lambda bond: bond.GetBondType(),
+        "IsAromatic": lambda bond: bond.GetIsAromatic(),
+        "IsConjugated": lambda bond: bond.GetIsConjugated(),
+        "IsInRing": lambda bond: bond.IsInRing(),
+        "Stereo": lambda bond: bond.GetStereo()
     }
 
     mol_fun_dict = {
@@ -269,6 +283,10 @@ class MolecularGraphRDKit(MolGraphInterface):
         """
         # Make molecule from smile via rdkit
         m = rdkit.Chem.MolFromSmiles(smile)
+        if m is None:
+            print("ERROR:kgcnn: Rdkit can not convert smile %s" % smile)
+            return self
+
         if sanitize:
             rdkit.Chem.SanitizeMol(m)
         if self._add_hydrogen:
@@ -306,20 +324,33 @@ class MolecularGraphRDKit(MolGraphInterface):
 
         return np.array(self.mol.GetConformers()[0].GetPositions())
 
+    def to_smiles(self):
+        if self.mol is None:
+            return
+        return rdkit.Chem.MolToSmiles(self.mol)
+
     def from_mol_block(self, mb, sanitize=False):
+        if mb is None or len(mb) == 0:
+            return self
         self.mol = rdkit.Chem.MolFromMolBlock(mb, removeHs=(not self._add_hydrogen), sanitize=sanitize)
         return self
 
     def to_mol_block(self):
+        if self.mol is None:
+            return None
         return rdkit.Chem.MolToMolBlock(self.mol)
 
     @property
     def node_symbol(self):
-        return [rdkit.Chem.rdchem.Atom.GetSymbol(x) for x in self.mol.GetAtoms()]
+        return [x.GetSymbol() for x in self.mol.GetAtoms()]
 
     @property
     def node_number(self):
-        return np.array([rdkit.Chem.rdchem.Atom.GetAtomicNum(x) for x in self.mol.GetAtoms()])
+        return np.array([x.GetAtomicNum() for x in self.mol.GetAtoms()])
+
+    @property
+    def edge_number(self):
+        return self.edge_attributes(["BondType"], encoder={"BondType": int})
 
     @property
     def edge_indices(self):
@@ -329,7 +360,7 @@ class MolecularGraphRDKit(MolGraphInterface):
             bond_idx.append([x.GetEndAtomIdx(), x.GetBeginAtomIdx()])
             if not self.is_directed:
                 # Add a bond with opposite direction but same properties
-                bond_idx.append([x.GetEndAtomIdx(), x.GetBeginAtomIdx()])
+                bond_idx.append([x.GetBeginAtomIdx(), x.GetEndAtomIdx()])
         # Sort directed bonds
         bond_idx = np.array(bond_idx, dtype="int64")
         if len(bond_idx) > 0:
@@ -352,13 +383,17 @@ class MolecularGraphRDKit(MolGraphInterface):
         for i, x in enumerate(m.GetBonds()):
             attr = []
             for k in edges:
-                attr += encoder[k](self.bond_fun_dict[k](x)) if k in encoder else [self.bond_fun_dict[k](x)]
+                temp = encoder[k](self.bond_fun_dict[k](x)) if k in encoder else [self.bond_fun_dict[k](x)]
+                if isinstance(temp, (list, tuple)):
+                    attr += list(temp)
+                else:
+                    attr.append(temp)
             bond_info.append(attr)
             bond_idx.append([x.GetEndAtomIdx(), x.GetBeginAtomIdx()])
             # Add a bond with opposite direction but same properties
             if not self.is_directed:
                 bond_info.append(attr)
-                bond_idx.append([x.GetEndAtomIdx(), x.GetBeginAtomIdx()])
+                bond_idx.append([x.GetBeginAtomIdx(), x.GetEndAtomIdx()])
 
         # Sort directed bonds
         bond_idx = np.array(bond_idx, dtype="int64")
@@ -383,7 +418,11 @@ class MolecularGraphRDKit(MolGraphInterface):
         for i, atm in enumerate(m.GetAtoms()):
             attr = []
             for k in nodes:
-                attr += encoder[k](self.atom_fun_dict[k](atm)) if k in encoder else [self.atom_fun_dict[k](atm)]
+                temp = encoder[k](self.atom_fun_dict[k](atm)) if k in encoder else [self.atom_fun_dict[k](atm)]
+                if isinstance(temp, (list, tuple)):
+                    attr += list(temp)
+                else:
+                    attr.append(temp)
             atom_info.append(attr)
         return atom_info
 
@@ -392,7 +431,11 @@ class MolecularGraphRDKit(MolGraphInterface):
         m = self.mol
         encoder = self._check_encoder(encoder, sorted(self.mol_fun_dict.keys()))
         # Mol info
-        mol_info = []
+        attr = []
         for k in graph:
-            mol_info += encoder[k](self.mol_fun_dict[k](m)) if k in encoder else [self.mol_fun_dict[k](m)]
-        return mol_info
+            temp = encoder[k](self.mol_fun_dict[k](m)) if k in encoder else [self.mol_fun_dict[k](m)]
+            if isinstance(temp, (list, tuple)):
+                attr += list(temp)
+            else:
+                attr.append(temp)
+        return attr
